import { Emitter } from 'strict-event-emitter';
import { WebSocketClientConnection, WebSocketServerConnection } from '@mswjs/interceptors/WebSocket';
import { PathParams, Path, Match } from '../utils/matching/matchRequestUrl.mjs';

type WebSocketHandlerParsedResult = {
    match: Match;
};
type WebSocketHandlerEventMap = {
    connection: [
        args: {
            client: WebSocketClientConnection;
            server: WebSocketServerConnection;
            params: PathParams;
        }
    ];
};
type WebSocketHandlerIncomingEvent = MessageEvent<{
    client: WebSocketClientConnection;
    server: WebSocketServerConnection;
}>;
declare const kEmitter: unique symbol;
declare const kDispatchEvent: unique symbol;
declare const kDefaultPrevented: unique symbol;
declare class WebSocketHandler {
    private readonly url;
    protected [kEmitter]: Emitter<WebSocketHandlerEventMap>;
    constructor(url: Path);
    parse(args: {
        event: WebSocketHandlerIncomingEvent;
    }): WebSocketHandlerParsedResult;
    predicate(args: {
        event: WebSocketHandlerIncomingEvent;
        parsedResult: WebSocketHandlerParsedResult;
    }): boolean;
    [kDispatchEvent](event: MessageEvent<any>): Promise<void>;
}

export { WebSocketHandler, type WebSocketHandlerEventMap, kDefaultPrevented, kDispatchEvent, kEmitter };
