import { Emitter } from "strict-event-emitter";
import {
  matchRequestUrl
} from '../utils/matching/matchRequestUrl.mjs';
const kEmitter = Symbol("kEmitter");
const kDispatchEvent = Symbol("kDispatchEvent");
const kDefaultPrevented = Symbol("kDefaultPrevented");
class WebSocketHandler {
  constructor(url) {
    this.url = url;
    this[kEmitter] = new Emitter();
  }
  [kEmitter];
  parse(args) {
    const connection = args.event.data;
    const match = matchRequestUrl(connection.client.url, this.url);
    return {
      match
    };
  }
  predicate(args) {
    return args.parsedResult.match.matches;
  }
  async [kDispatchEvent](event) {
    const parsedResult = this.parse({ event });
    const shouldIntercept = this.predicate({ event, parsedResult });
    if (!shouldIntercept) {
      return;
    }
    if (!Reflect.get(event, kDefaultPrevented)) {
      Reflect.set(event, kDefaultPrevented, true);
    }
    const connection = event.data;
    this[kEmitter].emit("connection", {
      client: connection.client,
      server: connection.server,
      params: parsedResult.match.params || {}
    });
  }
}
export {
  WebSocketHandler,
  kDefaultPrevented,
  kDispatchEvent,
  kEmitter
};
//# sourceMappingURL=WebSocketHandler.mjs.map