import {
  WebSocketHandler,
  kDefaultPrevented,
  kDispatchEvent
} from '../handlers/WebSocketHandler.mjs';
import { webSocketInterceptor } from '../ws/webSocketInterceptor.mjs';
function handleWebSocketEvent(getCurrentHandlers) {
  webSocketInterceptor.on("connection", (connection) => {
    const handlers = getCurrentHandlers();
    const connectionEvent = new MessageEvent("connection", {
      data: connection
      /**
       * @note This message event should be marked as "cancelable"
       * to have its default prevented using "event.preventDefault()".
       * There's a bug in Node.js that breaks the "cancelable" flag.
       * @see https://github.com/nodejs/node/issues/51767
       */
    });
    Object.defineProperty(connectionEvent, kDefaultPrevented, {
      enumerable: false,
      writable: true,
      value: false
    });
    for (const handler of handlers) {
      if (handler instanceof WebSocketHandler) {
        handler[kDispatchEvent](connectionEvent);
      }
    }
    if (!Reflect.get(connectionEvent, kDefaultPrevented)) {
      connection.server.connect();
      connection.client.addEventListener("message", (event) => {
        connection.server.send(event.data);
      });
    }
  });
}
export {
  handleWebSocketEvent
};
//# sourceMappingURL=handleWebSocketEvent.mjs.map